Models
======
.. automodapi:: pykeen.models
    :no-heading:
    :headings: --

Base Classes
------------
.. automodapi:: pykeen.models.base
    :no-inheritance-diagram:
    :no-heading:
    :headings: ~~

Initialization
--------------
.. automodule:: pykeen.models.init
    :members:
